Clazz.declarePackage("JSV.exception");
Clazz.load(["java.lang.Exception"], "JSV.exception.JSVException", null, function(){
var c$ = Clazz.declareType(JSV.exception, "JSVException", Exception);
});
;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
